﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media.Imaging;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 파일 정보 리스트
        /// </summary>
        private List<FileInfo> fileInfoList;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            Loaded                        += Window_Loaded;
            this.listBox.SelectionChanged += listBox_SelectionChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 윈도우 로드시 처리하기 - Window_Loaded(sender, e)

        /// <summary>
        /// 윈도우 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Window_Loaded(object sender, EventArgs e)
        {
            this.fileInfoList = GetFileInfoList();

            this.listBox.DataContext = this.fileInfoList;
        }

        #endregion
        #region 리스트 박스 선택 변경시 처리하기 - listBox_SelectionChanged(sender, e)

        /// <summary>
        /// 리스트 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void listBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ListBox listBox = sender as ListBox;

            int? index = listBox?.SelectedIndex;

            if(index >= 0)
            {
                string filePath = listBox.SelectedItem.ToString();

                if(!string.IsNullOrEmpty(filePath))
                {
                    Uri uri = new Uri(filePath);

                    BitmapImage bitmapImage = new BitmapImage(uri);

                    FileInfo fileInfo = new FileInfo(filePath);

                    this.image.Source = bitmapImage;

                    this.imageSizeTextBlock.Text   = bitmapImage.PixelWidth + " X " + bitmapImage.PixelHeight;
                    this.imageFormatTextBlock.Text = bitmapImage.Format.ToString();
                    this.fileSizeTextBlock.Text    = ((fileInfo.Length + 512) / 1024) + "K";
                }
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 파일 정보 리스트 구하기 - GetFileInfoList()

        /// <summary>
        /// 파일 정보 리스트 구하기
        /// </summary>
        /// <returns>파일 정보 리스트</returns>
        private List<FileInfo> GetFileInfoList()
        {
            List<FileInfo> fileInfoList = new List<FileInfo>();

            string currentDirectoryPath = Directory.GetCurrentDirectory();

            string imageDirectoryPath = Path.Combine(currentDirectoryPath, "IMAGE");

            string[] filePathArray = Directory.GetFiles(imageDirectoryPath, "*.jpg");

            foreach(string filePath in filePathArray)
            {
                FileInfo fileInfo = new FileInfo(filePath);

                fileInfoList.Add(fileInfo);
            }

            return fileInfoList;
        }

        #endregion
    }
}